@@ -2,5 +2,5 @@ from .. import Provider as BankProvider
 
 
 class Provider(BankProvider):
-    bban_format = '################'
+    bban_format = '##############'
     country_code = 'FI'
