@@ -1,11 +1,11 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from collections import OrderedDict
 
 from .. import BaseProvider
 
+localized = True
 
-class CreditCard(object):
+
+class CreditCard:
 
     def __init__(
             self,
@@ -29,7 +29,9 @@ class Provider(BaseProvider):
     # * https://creditcardjs.com/credit-card-type-detection
     prefix_maestro = ['5018', '5020', '5038', '56##', '57##', '58##',
                       '6304', '6759', '6761', '6762', '6763', '0604', '6390']
-    prefix_mastercard = ['51', '52', '53', '54', '55', '222%']
+    prefix_mastercard = ['51', '52', '53', '54', '55', '222%', '223', '224',
+                         '225', '226', '227', '228', '229', '23', '24', '25',
+                         '26', '270', '271', '2720']
     prefix_visa = ['4']
     prefix_amex = ['34', '37']
     prefix_discover = ['6011', '65']
@@ -44,6 +46,7 @@ class Provider(BaseProvider):
                                   prefix_mastercard, 16, security_code='CVV')),
         ('visa16', CreditCard('VISA 16 digit', prefix_visa)),
         ('visa13', CreditCard('VISA 13 digit', prefix_visa, 13)),
+        ('visa19', CreditCard('VISA 19 digit', prefix_visa, 19)),
         ('amex', CreditCard('American Express', prefix_amex,
                             15, security_code='CID', security_code_length=4)),
         ('discover', CreditCard('Discover', prefix_discover)),
