@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as PersonProvider
 
 
@@ -10,7 +8,51 @@ class Provider(PersonProvider):
         '{{last_name}}, {{first_name}}',
     )
 
+    # First 20 names from here
+    # https://www.babycenter.in/l25020672/top-20-indian-boys-names-of-2016-photos
+    # Next 20 names from here
+    # https://www.babycenter.in/l25020674/top-20-indian-girls-names-of-2016-photos
     first_names = (
+        'मुहम्मद',
+        'आरव',
+        'अर्जुन',
+        'रायन',
+        'आद्विक',
+        'अथर्व',
+        'रेयांश',
+        'अयान',
+        'विहान',
+        'साई',
+        'अद्वैत',
+        'शौर्य',
+        'विआन',
+        'आरुष',
+        'इशान',
+        'अयांश',
+        'पार्थ',
+        'देन्यल',
+        'किआन',
+        'विवान',
+        'आद्या',
+        'अनन्या',
+        'शनाया',
+        'फ़ातिमा',
+        'श्री',
+        'अनाया',
+        'अनिका',
+        'मायरा',
+        'इनाया',
+        'अमायरा',
+        'आन्वी',
+        'स्वरा',
+        'ज़ारा',
+        'मरियम',
+        'आराध्या',
+        'तन्वी',
+        'दीया',
+        'अद्विका',
+        'ईवा',
+        'आव्या',
         'अभय',
         'आदित्य',
         'अजित',
@@ -93,7 +135,14 @@ class Provider(PersonProvider):
         'श्यामा',
         'सुलभा',
         'तृष्णा',
-        'विद्या')
+        'विद्या',
+        'अली',
+        'हासन',
+        'हुसैन',
+        'ज़ाकिर',
+        'रिज़वान',
+        'फ़रहान',
+        'ज़ोया')
 
     last_names = (
         'पाटिल',
@@ -180,4 +229,10 @@ class Provider(PersonProvider):
         'मान',
         'श्रीविमल',
         'कुमार',
-        'मंडल')
+        'मंडल',
+        'अली',
+        'हासन',
+        'हुसैन',
+        'खान',
+        'अब्बासी',
+        'नूरानी')
